@@ -25,7 +25,7 @@ dw_test_that("getDataset making the correct HTTR request", {
       expect_equal(user_agent$options$useragent, user_agent())
 
       return(
-        success_message_response_with_content(
+        success_message_with_content(
           "resources/api.data.world/v0/DatasetSummaryResponse.sample.json",
           "application/json"
         )
